"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TreeView = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _NodeList = _interopRequireDefault(require("./components/NodeList"));
var _helpers = require("./helpers");
var _treeView = require("./store/treeView.store");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const _TreeView = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    data,
    onCheck,
    onExpand,
    preselectedIds = [],
    treeFlashListProps,
    checkBoxViewStyleProps,
    CheckboxComponent,
    ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent,
    indentationMultiplier
  } = props;
  const {
    expanded,
    updateExpanded,
    initialTreeViewData,
    updateInitialTreeViewData,
    searchText,
    updateSearchText,
    updateSearchKeys,
    checked,
    cleanUpTreeViewStore
  } = (0, _treeView.useTreeViewStore)();
  _react.default.useImperativeHandle(ref, () => ({
    selectAll: _helpers.selectAll,
    unselectAll: _helpers.unselectAll,
    selectAllFiltered: _helpers.selectAllFiltered,
    unselectAllFiltered: _helpers.unselectAllFiltered,
    expandAll: _helpers.expandAll,
    collapseAll: _helpers.collapseAll,
    setSearchText
  }));
  function setSearchText(text) {
    let keys = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ["name"];
    updateSearchText(text);
    updateSearchKeys(keys);
  }
  _react.default.useEffect(() => {
    updateInitialTreeViewData(data);
    (0, _helpers.initializeNodeMaps)(data);

    // Check any preselected nodes
    (0, _helpers.toggleCheckboxes)(preselectedIds, true);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  const getIds = _react.default.useCallback(node => {
    if (!node.children || node.children.length === 0) {
      return [node.id];
    } else {
      return [node.id, ...node.children.flatMap(item => getIds(item))];
    }
  }, []);
  _react.default.useEffect(() => {
    onCheck && onCheck(Array.from(checked));
  }, [onCheck, checked]);
  _react.default.useEffect(() => {
    onExpand && onExpand(Array.from(expanded));
  }, [onExpand, expanded]);
  _react.default.useEffect(() => {
    if (searchText) {
      _reactNative.InteractionManager.runAfterInteractions(() => {
        updateExpanded(new Set(initialTreeViewData.flatMap(item => getIds(item))));
      });
    } else {
      _reactNative.InteractionManager.runAfterInteractions(() => {
        updateExpanded(new Set());
      });
    }
  }, [getIds, initialTreeViewData, searchText, updateExpanded]);
  _react.default.useEffect(() => {
    return () => {
      cleanUpTreeViewStore();
    };
  }, [cleanUpTreeViewStore]);
  return /*#__PURE__*/_react.default.createElement(_NodeList.default, {
    treeFlashListProps: treeFlashListProps,
    checkBoxViewStyleProps: checkBoxViewStyleProps,
    indentationMultiplier: indentationMultiplier,
    CheckboxComponent: CheckboxComponent,
    ExpandCollapseIconComponent: ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent: ExpandCollapseTouchableComponent
  });
});
const TreeView = /*#__PURE__*/_react.default.memo(_TreeView);
exports.TreeView = TreeView;
//# sourceMappingURL=TreeView.js.map